==> lyx-1.5.7-cygwin.tar.gz: usr/local/bin/lyxeditor.sh <==
#!/bin/sh
# Pass filename and line number of a latex file to the lyxpipe of a running
# instance of LyX. LyX will jump to the corresponding line in the .lyx file
# being previewed in either yap or xdvi.
# This script is directly invoked by the dvi viewer when initiating a
# reverse dvi search (yap uses double click, xdvi ctrl-click).
# When using yap, this script should be called through a wrapper batch file.
# Author: Enrico Forestieri.

# parse_serverpipe is by Angus Leeming
parse_serverpipe()
{
        # The output of this sed script is output to STDOUT
        LYXPIPE=`sed -n '/^\\\\serverpipe /{
# First consider that the file path may be quoted
s/^ *\\\\serverpipe \{1,\}\"\([^"]\{1,\}\)\" *$/\1/
tfound

# Now, unquoted
s/^ *\\\\serverpipe \{1,\}\(.*\)/\1/
s/ *$//

:found
# Change from single to double shell quoting temporarily...
'"
s@^~/@${HOME}/@
# Revert to single shell quotes
"'

p
q
}' "$1"`

        echo "${LYXPIPE}"
        unset LYXPIPE
}

LYXPIPE=""

for LYXDIR in .lyx .lyx-1.6.0svn .lyx-1.4.5 .lyx-1.3.7
do
	PREFERENCES="${HOME}/${LYXDIR}/preferences"
	test -r "${PREFERENCES}" || continue
	# See if preferences file contains a \serverpipe entry
	LYXPIPE=`parse_serverpipe "${PREFERENCES}"`
	# If it does and $LYXPIPE.in exists, break out of the loop
	test -n "${LYXPIPE}" -a -r "${LYXPIPE}".in && break || LYXPIPE=""
done


test -z "${LYXPIPE}" && {
	# The preferences file does not set lyxpipe, so check lyxrc.dist
	LYXRC_DIST="/usr/local/share/lyx/lyxrc.dist"
        test -r "${LYXRC_DIST}" || exit
	# See if lyxrc.dist contains a \serverpipe entry
	LYXPIPE=`parse_serverpipe "${LYXRC_DIST}"`
	# If it does not, or $LYXPIPE.in does not exists, exit
	test -z "${LYXPIPE}" -o ! -r "${LYXPIPE}".in && exit
}

# Let's do the job

file=`cygpath $1`

echo "Using the lyxpipe ${LYXPIPE}"
COMMAND="LYXCMD:revdvi:server-goto-file-row:$file $2"
echo "$COMMAND"
echo "$COMMAND" > "${LYXPIPE}".in || exit
read < "${LYXPIPE}".out || exit

==> lyx-1.6.2-cygwin.tar.gz: usr/local/bin/lyxeditor.sh <==
#!/bin/sh
# Pass filename and line number of a latex file to the lyxpipe of a running
# instance of LyX. LyX will jump to the corresponding line in the .lyx file
# being previewed in either yap or xdvi.
# This script is directly invoked by the dvi viewer when initiating a
# reverse dvi search (yap uses double click, xdvi ctrl-click).
# When using yap, this script should be called through a wrapper batch file.
# Author: Enrico Forestieri.

# parse_serverpipe is by Angus Leeming
parse_serverpipe()
{
        # The output of this sed script is output to STDOUT
        LYXPIPE=`sed -n '/^\\\\serverpipe /{
# First consider that the file path may be quoted
s/^ *\\\\serverpipe \{1,\}\"\([^"]\{1,\}\)\" *$/\1/
tfound

# Now, unquoted
s/^ *\\\\serverpipe \{1,\}\(.*\)/\1/
s/ *$//

:found
# Change from single to double shell quoting temporarily...
'"
s@^~/@${HOME}/@
# Revert to single shell quotes
"'

p
q
}' "$1"`

        echo "${LYXPIPE}"
        unset LYXPIPE
}

LYXPIPE=""

for LYXDIR in .lyx .lyx-2.0 .lyx-1.6 .lyx-1.4.5 .lyx-1.3.7
do
	PREFERENCES="${HOME}/${LYXDIR}/preferences"
	test -r "${PREFERENCES}" || continue
	# See if preferences file contains a \serverpipe entry
	LYXPIPE=`parse_serverpipe "${PREFERENCES}"`
	# If it does and $LYXPIPE.in exists, break out of the loop
	test -n "${LYXPIPE}" -a -r "${LYXPIPE}".in && break || LYXPIPE=""
done


test -z "${LYXPIPE}" && {
	# The preferences file does not set lyxpipe, so check lyxrc.dist
	LYXRC_DIST="/usr/local/share/lyx/lyxrc.dist"
        test -r "${LYXRC_DIST}" || exit
	# See if lyxrc.dist contains a \serverpipe entry
	LYXPIPE=`parse_serverpipe "${LYXRC_DIST}"`
	# If it does not, or $LYXPIPE.in does not exists, exit
	test -z "${LYXPIPE}" -o ! -r "${LYXPIPE}".in && exit
}

# Let's do the job

file=`cygpath $1`

echo "Using the lyxpipe ${LYXPIPE}"
COMMAND="LYXCMD:revdvi:server-goto-file-row:$file $2"
echo "$COMMAND"
echo "$COMMAND" > "${LYXPIPE}".in || exit
read < "${LYXPIPE}".out || exit
